==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/WebSwitchDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCheckboxBaseDescriptionMetadata } from "./WebCheckboxBaseDescriptionMetadata";
import { WebSwitchDescription } from "./WebSwitchDescription";
/**
 * @hidden
 */
var WebSwitchDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebSwitchDescriptionMetadata, _super);
    function WebSwitchDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSwitchDescriptionMetadata.b = function (a) {
        if (WebSwitchDescriptionMetadata.a == null) {
            WebSwitchDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSwitchDescriptionMetadata.c(WebSwitchDescriptionMetadata.a);
        }
        if (a.g(WebSwitchDescriptionMetadata.a)) {
            return;
        }
        a.s(WebSwitchDescriptionMetadata.a);
    };
    WebSwitchDescriptionMetadata.c = function (a) {
        WebCheckboxBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Switch");
    };
    WebSwitchDescriptionMetadata.d = function (a) {
        WebSwitchDescriptionMetadata.b(a);
        a.u("WebSwitch", function () { return new WebSwitchDescription(); });
        a.t("WebSwitch", WebSwitchDescriptionMetadata.a);
    };
    WebSwitchDescriptionMetadata.$t = markType(WebSwitchDescriptionMetadata, 'WebSwitchDescriptionMetadata');
    WebSwitchDescriptionMetadata.a = null;
    return WebSwitchDescriptionMetadata;
}(Base));
export { WebSwitchDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebSwitchDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCheckboxBaseDescriptionMetadata } from "./WebCheckboxBaseDescriptionMetadata";
import { WebSwitchDescription } from "./WebSwitchDescription";
/**
 * @hidden
 */
var WebSwitchDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebSwitchDescriptionMetadata, _super);
    function WebSwitchDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSwitchDescriptionMetadata.b = function (a) {
        if (WebSwitchDescriptionMetadata.a == null) {
            WebSwitchDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSwitchDescriptionMetadata.c(WebSwitchDescriptionMetadata.a);
        }
        if (a.j(WebSwitchDescriptionMetadata.a)) {
            return;
        }
        a.y(WebSwitchDescriptionMetadata.a);
    };
    WebSwitchDescriptionMetadata.c = function (a) {
        WebCheckboxBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Switch");
        a.item("__tagNameWC", "String:igc-switch");
    };
    WebSwitchDescriptionMetadata.d = function (a) {
        WebSwitchDescriptionMetadata.b(a);
        a.aa("WebSwitch", function () { return new WebSwitchDescription(); });
        a.z("WebSwitch", WebSwitchDescriptionMetadata.a);
    };
    WebSwitchDescriptionMetadata.$t = markType(WebSwitchDescriptionMetadata, 'WebSwitchDescriptionMetadata');
    WebSwitchDescriptionMetadata.a = null;
    return WebSwitchDescriptionMetadata;
}(Base));
export { WebSwitchDescriptionMetadata };
